@@ -220,7 +220,9 @@ class ContainersCommands(ServicesCommands):
         """Steps to compile translations for the instance."""
         commands = TranslationsCommands(
             project_path=self.cli_config.get_project_dir(),
-            instance_path=self.cli_config.get_instance_path(),
+            # we use INVENIO_INSTANCE_PATH that is set in the Dockerfile as
+            # config.instance_path is set only in development `install` command
+            instance_path="${INVENIO_INSTANCE_PATH}",
         )
         cmd = commands.compile(
             # instance path inside the container
@@ -237,7 +239,7 @@ class ContainersCommands(ServicesCommands):
                     "project_shortname": project_shortname,
                     "command": cmd,
                 },
-                message="Compilating message catalog...",
+                message="Compiling message catalog...",
                 skippable=True,
             ),
         ]
