@@ -11,5 +11,5 @@
 
 from .cookiecutter_wrapper import CookiecutterWrapper
 from .docker_helper import DockerHelper
+from .env import env
 from .filesystem import get_created_files
-from .log import LoggingConfig, LogPipe
